##  Linking Discovered Items to the Fact Sheets
Once an integration is successfully set up, the discovered SaaS applications are listed in the SaaS Discovery Inbox. In the inbox, you can review the discovered items and link them to existing fact sheets or create and link new fact sheets. To learn more, see [SaaS Discovery Inbox](https://help.sap.com/docs/leanix/ea/saas-discovery-inbox?locale=en-US&state=PRODUCTION&version=CLOUD "Discovered SaaS applications are listed in the SaaS discovery inbox. Learn how to link the discovered items to fact sheets or review and reject them as needed.").
